#!/usr/bin/env bash

ABSDIR="$( dirname "$(readlink -f -- "$0")" )"
source "${ABSDIR}"/../functions.sh
source "${ABSDIR}"/vars.sh

ensure_pwd_is_scriptdir
ensure_not_root

buildfolder=/tmp/privatebin-$$

if ! podman image exists ${privatebin_image}:${privatebin_version}; then
    if git clone -b ${privatebin_version} --depth=1 https://github.com/PrivateBin/docker-nginx-fpm-alpine ${buildfolder} ; then
	sed -i "s#mv cfg lib tpl vendor /srv#mv cfg lib tpl vendor /srv \&\& sed -i \\'/Content-Security-Policy\\\|X-XSS-Protection\\\|X-Frame-Options\\\|X-Content-Type-Options/d\\' /srv/lib/Controller.php#" ${buildfolder}/Dockerfile &&
        TMPDIR=${HOME} podman image build \
	       -t "${privatebin_image}":"${privatebin_version}" \
	       ${buildfolder} || retval=false
	podman image prune -a -f --filter dangling=true
	podman image prune -a -f --filter intermediate=true
	podman image rm -f $(podman image list -a -q -- docker.io/library/alpine)
    fi
    rm -rf ${buildfolder}
    eval "$retval"
else
    echo "Image ${privatebin_image}:${privatebin_version} already built"
fi &&

oci_push_to_registry ${privatebin_image}:${privatebin_version}
